@@ -92,6 +92,13 @@ class PackageBuild:
             'git push -f origin master',  # 6.Finally, force update your repository
         ])
 
+    def git_clean(self):
+        """
+        git build
+        """
+        logger.info('{} clean'.format(self.name))
+        run_shell_list(['git gc --aggressive'])
+
 
 def command_line_parser():
     parser = argparse.ArgumentParser(description="Test")
